@@ -5,9 +5,9 @@ import os
 from PyQt4 import uic
 from PyQt4 import QtGui
 
+from ubiquity import i18n, misc
 from ubiquity.frontend.kde_components.PartitionBar import PartitionsBar
-from ubiquity import misc
-from ubiquity import i18n
+
 
 _uidir = "/usr/share/ubiquity/qt/"
 
@@ -161,16 +161,16 @@ class PartAuto(QtGui.QWidget):
             disks.append((text, bar_frame))
 
             dev = self.diskLayout[path.rsplit('/', 1)[1]]
-            before_bar = PartitionsBar()
-            after_bar = PartitionsBar()
+            before_bar = PartitionsBar(controller=self.controller)
+            after_bar = PartitionsBar(controller=self.controller)
 
             for p in dev:
                 before_bar.addPartition(p.device, int(p.size), p.filesystem)
             if before_bar.diskSize > 0:
                 after_bar.addPartition(
-                    release_name, before_bar.diskSize, 'auto')
+                    '', before_bar.diskSize, 'auto', name=release_name)
             else:
-                after_bar.addPartition(release_name, 1, 'auto')
+                after_bar.addPartition('', 1, 'auto', name=release_name)
 
             addBars(bar_frame, before_bar, after_bar)
         self.disks.append(disks)
@@ -288,15 +288,25 @@ class PartAuto(QtGui.QWidget):
             self.password.setEnabled(True)
             self.verified_password.setEnabled(True)
             self.badPassword.setEnabled(True)
+            self.verify_password()
         else:
             self.passwordIcon.setEnabled(False)
             self.password.setEnabled(False)
             self.verified_password.setEnabled(False)
             self.badPassword.setEnabled(False)
+            self.controller.allow_go_forward(True)
 
     #show warning if passwords do not match
     def verify_password(self):
-        if self.password.text() != self.verified_password.text():
-            self.badPassword.show()
-        else:
+        complete = False
+
+        if self.password.text() == self.verified_password.text():
             self.badPassword.hide()
+            complete = True
+        else:
+            self.badPassword.show()
+
+        if not self.password.text():
+            complete = False
+
+        self.controller.allow_go_forward(complete)
