@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
 
-import sys
 import os
+import sys
 
 from PyQt4 import QtGui
 
 from ubiquity.frontend.kde_components.PartMan import PartMan
 
+
 if __name__ == "__main__":
 
     app = QtGui.QApplication(sys.argv)
@@ -74,8 +75,6 @@ if __name__ == "__main__":
                 ('25filesystem', 'ext3', 'Ext3 journaling file system'),
                 ('25filesystem', 'ext2', 'Ext2 file system'),
                 ('25filesystem', 'btrfs', 'btrfs journaling file system'),
-                ('25filesystem', 'reiserfs',
-                 'ReiserFS journaling file system'),
                 ('25filesystem', 'jfs', 'JFS journaling file system'),
                 ('25filesystem', 'xfs', 'XFS journaling file system'),
                 ('25filesystem', 'fat16', 'FAT16 file system'),
@@ -109,8 +108,6 @@ if __name__ == "__main__":
                 ('25filesystem', 'ext3', 'Ext3 journaling file system'),
                 ('25filesystem', 'ext2', 'Ext2 file system'),
                 ('25filesystem', 'btrfs', 'btrfs journaling file system'),
-                ('25filesystem', 'reiserfs',
-                 'ReiserFS journaling file system'),
                 ('25filesystem', 'jfs', 'JFS journaling file system'),
                 ('25filesystem', 'xfs', 'XFS journaling file system'),
                 ('25filesystem', 'fat16', 'FAT16 file system'),
@@ -143,8 +140,6 @@ if __name__ == "__main__":
                 ('25filesystem', 'ext3', 'Ext3 journaling file system'),
                 ('25filesystem', 'ext2', 'Ext2 file system'),
                 ('25filesystem', 'btrfs', 'btrfs journaling file system'),
-                ('25filesystem', 'reiserfs',
-                 'ReiserFS journaling file system'),
                 ('25filesystem', 'jfs', 'JFS journaling file system'),
                 ('25filesystem', 'xfs', 'XFS journaling file system'),
                 ('25filesystem', 'fat16', 'FAT16 file system'),
@@ -178,8 +173,6 @@ if __name__ == "__main__":
                 ('25filesystem', 'ext3', 'Ext3 journaling file system'),
                 ('25filesystem', 'ext2', 'Ext2 file system'),
                 ('25filesystem', 'btrfs', 'btrfs journaling file system'),
-                ('25filesystem', 'reiserfs',
-                 'ReiserFS journaling file system'),
                 ('25filesystem', 'jfs', 'JFS journaling file system'),
                 ('25filesystem', 'xfs', 'XFS journaling file system'),
                 ('25filesystem', 'fat16', 'FAT16 file system'),
@@ -212,8 +205,6 @@ if __name__ == "__main__":
                 ('25filesystem', 'ext3', 'Ext3 journaling file system'),
                 ('25filesystem', 'ext2', 'Ext2 file system'),
                 ('25filesystem', 'btrfs', 'btrfs journaling file system'),
-                ('25filesystem', 'reiserfs',
-                 'ReiserFS journaling file system'),
                 ('25filesystem', 'jfs', 'JFS journaling file system'),
                 ('25filesystem', 'xfs', 'XFS journaling file system'),
                 ('25filesystem', 'fat16', 'FAT16 file system'),
@@ -247,8 +238,6 @@ if __name__ == "__main__":
                 ('25filesystem', 'ext3', 'Ext3 journaling file system'),
                 ('25filesystem', 'ext2', 'Ext2 file system'),
                 ('25filesystem', 'btrfs', 'btrfs journaling file system'),
-                ('25filesystem', 'reiserfs',
-                 'ReiserFS journaling file system'),
                 ('25filesystem', 'jfs', 'JFS journaling file system'),
                 ('25filesystem', 'xfs', 'XFS journaling file system'),
                 ('25filesystem', 'fat16', 'FAT16 file system'),
