@@ -158,6 +158,7 @@ def grub_options():
         result = subp.communicate()[0].splitlines()
         for res in result:
             res = res.split(':')
+            res[0] = re.match(r'[/\w\d]+', res[0]).group()
             oslist[res[0]] = res[1]
         p = PartedServer()
         for disk in p.disks():
@@ -373,7 +374,10 @@ def grub_default(boot=None):
             else:
                 # Try the next disk along (which can't also be the CD source).
                 target = os.path.realpath(devices[1].split('\t')[1])
-            target = re.sub(r'(/dev/(cciss|ida)/c[0-9]d[0-9]|/dev/[a-z]+).*',
+            target = re.sub(r'(/dev/(cciss|ida)/c[0-9]d[0-9]|\
+                            /dev/nvme[0-9]+n[0-9]+|\
+                            /dev/[a-z]+\
+                            ).*',
                             r'\1', target)
         except (IndexError, OSError):
             pass
@@ -430,6 +434,8 @@ def os_prober():
         result = subp.communicate()[0].splitlines()
         for res in result:
             res = res.split(':')
+            # launchpad bug #1265192, fix os-prober Windows EFI path
+            res[0] = re.match(r'[/\w\d]+', res[0]).group()
             if res[2] == 'Ubuntu':
                 version = [v for v in re.findall('[0-9.]*', res[1]) if v][0]
                 # Get rid of the superfluous (development version) (11.04)
@@ -597,6 +603,15 @@ def create_bool(text):
         return text
 
 
+# On hardware that uses SMBIOS 2.8+, dmidecode 2.12 will contain this warning
+# message prefixed before system-version, system-product-name, etc.  This is
+# problematic as the default hostname built by Ubiquity wont be valid (it's too
+# long), so we strip this prefix.  Note there is no reason to forward-port this
+# to Xenial as it uses dmidecode 3.0, which doesn't have this problem.
+SMBIOS28_JUNK = 'SMBIOS-implementations-newer-than-version-2-8-are-not-fully-\
+supported-by-this-version-of-dmidecode-'
+
+
 @raise_privileges
 def dmimodel():
     model = ''
@@ -635,6 +650,8 @@ def dmimodel():
         model = re.sub('[^a-zA-Z0-9]+', '-', model).rstrip('-').lstrip('-')
         if model.lower() == 'not-available':
             return
+        if model.startswith(SMBIOS28_JUNK):
+            model = model[len(SMBIOS28_JUNK):]
     except Exception:
         syslog.syslog(syslog.LOG_ERR, 'Unable to determine the model from DMI')
     finally:
