@@ -1,6 +1,6 @@
 # -*- coding: utf-8; Mode: Python; indent-tabs-mode: nil; tab-width: 4 -*-
 
-# Copyright (C) 2010 Canonical Ltd.
+# Copyright (C) 2013 Canonical Ltd.
 # Written by Evan Dandrea <evan.dandrea@canonical.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -23,12 +23,11 @@ import os
 import subprocess
 import sys
 
-from ubiquity import plugin
-from ubiquity import misc, osextras, i18n, upower
+from ubiquity import i18n, misc, osextras, plugin, upower
 
 
 NAME = 'prepare'
-AFTER = 'language'
+AFTER = 'wireless'
 WEIGHT = 11
 OEM = False
 
@@ -205,8 +204,7 @@ class PageKde(PreparePageBase):
     def plugin_translate(self, lang):
         PreparePageBase.plugin_translate(self, lang)
         # gtk does the ${RELEASE} replace for the title in gtk_ui but we do
-        # it per plugin because our title widget is per plugin.  Also add
-        # Bold here (not sure how the gtk side keeps that formatting).
+        # it per plugin because our title widget is per plugin
         release = misc.get_release()
         widgets = (
             self.page.prepare_heading_label,
@@ -217,7 +215,6 @@ class PageKde(PreparePageBase):
             text = widget.text()
             text = text.replace('${RELEASE}', release.name)
             text = text.replace('Ubuntu', 'Kubuntu')
-            text = "<b>" + text + "</b>"
             widget.setText(text)
 
 
